@@ -24,11 +24,8 @@
 
 // Qt
 #include <QObject>
-#include <QPointer>
-#include <QHash>
 #include <QList>
 #include <QTabWidget>
-#include <QTabBar>
 
 // Konsole
 #include "Profile.h"
@@ -57,7 +54,7 @@ class TabbedViewContainer;
  * to actually add or remove view widgets from the container widget, as well
  * as updating any navigation aids.
  */
-class TabbedViewContainer : public QTabWidget
+class KONSOLEPRIVATE_EXPORT TabbedViewContainer : public QTabWidget
 {
     Q_OBJECT
 
@@ -78,13 +75,11 @@ public:
     ~TabbedViewContainer() Q_DECL_OVERRIDE;
 
     /** Adds a new view to the container widget */
-    void addView(QWidget *view, ViewProperties *item, int index = -1);
+    void addView(TerminalDisplay *view, int index = -1);
 
     /** Removes a view from the container */
-    void removeView(QWidget *view);
+    void removeView(TerminalDisplay *view);
 
-    /** Returns the ViewProperties instance associated with a particular view in the container */
-    ViewProperties *viewProperties(QWidget *view) const;
     void setTabActivity(int index, bool activity);
 
     void updateTitle(ViewProperties *item);
@@ -100,6 +95,13 @@ public:
     /** Changes the active view to the last view */
     void activateLastView();
 
+    /** Changes the active view to the last used view */
+    void activateLastUsedView(bool reverse);
+
+    /** Toggle between last two views */
+    void toggleLastUsedView();
+
+    void setCss(const QString& styleSheet = QString());
     void setCssFromFile(const QUrl& url);
     /**
      * This enum describes the directions
@@ -137,45 +139,48 @@ public:
     void openTabContextMenu(const QPoint &point);
     void setNavigationVisibility(ViewManager::NavigationVisibility navigationVisibility);
     void moveTabToWindow(int index, QWidget *window);
+
+    /* return the widget(int index) casted to TerminalDisplay*
+     *
+     * The only thing that this class holds are TerminalDisplays, so
+     * this is the only thing that should be used to retrieve widgets.
+     */
+    TerminalDisplay *terminalAt(int index);
 Q_SIGNALS:
     /** Emitted when the container has no more children */
     void empty(TabbedViewContainer *container);
 
     /** Emitted when the user requests to open a new view */
-    void newViewRequest();
+    void newViewRequest(TabbedViewContainer *thisContainer);
 
     /** Requests creation of a new view, with the selected profile. */
-    void newViewRequest(Profile::Ptr);
+    void newViewWithProfileRequest(TabbedViewContainer *thisContainer, const Profile::Ptr&);
 
     /**
      * Emitted when the user requests to move a view from another container
      * into this container.  If 'success' is set to true by a connected slot
      * then the original view will be removed.
      *
-     * @param index Index at which to insert the new view in the container or -1
-     * to append it.  This index should be passed to addView() when the new view
-     * has been created.
-     * @param id The identifier of the view.
-     * @param sourceContainer Initial move event Tabbed view container.
+     * @param index Index at which to insert the new view in the container
+     * or -1 to append it.  This index should be passed to addView() when
+     * the new view has been created.
+     * @param sessionControllerId The identifier of the view.
      */
-    void moveViewRequest(int index, int id, TabbedViewContainer *sourceContainer);
+    void moveViewRequest(int index, int sessionControllerId);
 
     /** Emitted when the active view changes */
-    void activeViewChanged(QWidget *view);
+    void activeViewChanged(TerminalDisplay *view);
 
     /** Emitted when a view is added to the container. */
-    void viewAdded(QWidget *view, ViewProperties *properties);
+    void viewAdded(TerminalDisplay *view);
 
     /** Emitted when a view is removed from the container. */
-    void viewRemoved(QWidget *view);
+    void viewRemoved(TerminalDisplay *view);
 
     /** detach the specific tab */
-    void detachTab(TabbedViewContainer *self, QWidget *activeView);
+    void detachTab(TabbedViewContainer *self, TerminalDisplay *activeView);
 
 protected:
-    /** Returns the widgets which are associated with a particular navigation item */
-    QList<QWidget *> widgetsForItem(ViewProperties *item) const;
-
     /**
      * Rearranges the order of widgets in the container.
      *
@@ -186,20 +191,24 @@ protected:
 
     // close tabs and unregister
     void closeTerminalTab(int idx);
+
+    void keyReleaseEvent(QKeyEvent *event) Q_DECL_OVERRIDE;
 private Q_SLOTS:
     void viewDestroyed(QObject *view);
     void konsoleConfigChanged();
 
 private:
-    void forgetView(QWidget *view);
+    void forgetView(TerminalDisplay *view);
+    void updateTabHistory(TerminalDisplay *view, bool remove = false);
 
-    QHash<QWidget *, ViewProperties *> _navigation;
+    QList<TerminalDisplay *> _tabHistory;
     ViewManager *_connectedViewManager;
     QMenu *_contextPopupMenu;
     QToolButton *_newTabButton;
     QToolButton *_closeTabButton;
     int _contextMenuTabIndex;
     ViewManager::NavigationVisibility _navigationVisibility;
+    int _tabHistoryIndex;
 };
 
 
