@@ -89,7 +89,7 @@ ViewSplitter *ViewSplitter::activeSplitter()
 void ViewSplitter::registerContainer(TabbedViewContainer *container)
 {
     _containers << container;
-    connect(container, SIGNAL(empty(TabbedViewContainer*)), this, SLOT(containerEmpty(TabbedViewContainer*)));
+    connect(container, &TabbedViewContainer::empty, this, &ViewSplitter::containerEmpty);
 }
 
 void ViewSplitter::unregisterContainer(TabbedViewContainer *container)
@@ -188,6 +188,18 @@ void ViewSplitter::containerEmpty(TabbedViewContainer * myContainer)
     if (children == 0) {
         emit allContainersEmpty();
     }
+
+    // This container is no more, try to find another container to focus.
+    ViewSplitter *currentSplitter = activeSplitter();
+    while(qobject_cast<ViewSplitter*>(currentSplitter->parent())) {
+        currentSplitter = qobject_cast<ViewSplitter*>(currentSplitter->parent());
+    }
+
+    for(auto tabWidget : currentSplitter->findChildren<TabbedViewContainer*>()) {
+        if (tabWidget != myContainer && tabWidget->count()) {
+            tabWidget->setCurrentIndex(0);
+        }
+    }
 }
 
 void ViewSplitter::activateNextContainer()
@@ -255,10 +267,10 @@ TabbedViewContainer *ViewSplitter::activeContainer() const
 
     QList<ViewSplitter *> splitters = findChildren<ViewSplitter *>();
 
-    if (splitters.count() > 0) {
+    if (!splitters.isEmpty()) {
         return splitters.last()->activeContainer();
     } else {
-        if (_containers.count() > 0) {
+        if (!_containers.isEmpty()) {
             return _containers.last();
         } else {
             return nullptr;
